@@ -744,7 +744,7 @@ static int nvkms_ioctl(
     u_long cmd,
     caddr_t data,
     int fflag,
-    d_thread_t *td
+    struct thread *td
 )
 {
     u_long nr, size;
@@ -774,7 +774,6 @@ static int nvkms_ioctl(
     sx_xlock(&nvkms_lock);
     ret = nvKmsIoctl(popen->data,
                      params->cmd,
-                     NVKMS_CLIENT_USER_SPACE,
                      params->address,
                      params->size);
     sx_xunlock(&nvkms_lock);
@@ -786,7 +785,7 @@ static int nvkms_open(
     struct cdev *dev,
     int oflags,
     int devtype,
-    d_thread_t *td
+    struct thread *td
 )
 {
     struct nvkms_per_open *popen;
@@ -802,7 +801,7 @@ static int nvkms_open(
     nvkms_module.client_counter += 1;
     sx_xunlock(&nvkms_module.lock);
 
-    popen = nvkms_alloc(sizeof(*popen), NV_FALSE);
+    popen = nvkms_alloc(sizeof(*popen), NV_TRUE);
     if (popen == NULL) {
         return ENOMEM;
     }
@@ -821,7 +820,7 @@ static int nvkms_open(
     mtx_init(&popen->events.lock, "nvkms-events-lock", NULL, 0);
 
     sx_xlock(&nvkms_lock);
-    popen->data = nvKmsOpen(popen);
+    popen->data = nvKmsOpen(curproc->p_pid, NVKMS_CLIENT_USER_SPACE, popen);
     sx_xunlock(&nvkms_lock);
 
     /*
@@ -834,7 +833,7 @@ static int nvkms_open(
 static int nvkms_poll(
     struct cdev *dev,
     int events,
-    d_thread_t *td
+    struct thread *td
 )
 {
     struct nvkms_per_open *popen;
